<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 8.6.0
 */

defined( 'ABSPATH' ) || exit;

$opt = get_option( 'saasland_opt' );

$shop_sidebar = !empty($opt['shop_sidebar']) ? $opt['shop_sidebar'] : '';
$is_sidebar = ( isset($opt['shop_sidebar']) && ($shop_sidebar == 'left' || $shop_sidebar == 'right') ) ? '9 shop_left' : '12';

get_header( 'shop' );
do_action( 'saaland_after_header' );

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 */
do_action( 'woocommerce_before_main_content' );
?>

<?php
    if (!is_active_sidebar( 'shop_sidebar' )) {
        if (woocommerce_product_loop()) {
            echo '<div class="row align-items-center">';
            /**
             * Hook: woocommerce_before_shop_loop.
             *
             * @hooked wc_print_notices - 10
             * @hooked woocommerce_result_count - 20
             * @hooked woocommerce_catalog_ordering - 30
             */
            do_action( 'woocommerce_before_shop_loop' );
            echo '</div>';
        }
    }

// Start page wrapper row
?>

<div class="row <?php echo esc_attr($shop_sidebar == 'left' ? 'flex-row-reverse' : ''); ?>">
    <div class="col-md-<?php echo esc_attr($is_sidebar); ?>">

        <?php if ( woocommerce_product_loop() ) : ?>
            <div class="row align-items-center">
                <?php
                /**
                 * Hook: woocommerce_before_shop_loop.
                 *
                 * @hooked wc_print_notices - 10
                 * @hooked woocommerce_result_count - 20
                 * @hooked woocommerce_catalog_ordering - 30
                 */
                do_action( 'woocommerce_before_shop_loop' );
                ?>
            </div>

            <?php woocommerce_product_loop_start(); ?>
            <div class="row">
            <?php if ( wc_get_loop_prop( 'total' ) ) : ?>
                <?php while ( have_posts() ) : ?>
                    <?php the_post(); ?>

                    <?php
                    /**
                     * Hook: woocommerce_shop_loop.
                     *
                     * @hooked WC_Structured_Data::generate_product_data() - 10
                     */
                    do_action( 'woocommerce_shop_loop' );

                    wc_get_template_part( 'content', 'product' );
                    ?>

                <?php endwhile; ?>
            <?php endif; ?>
            </div>

            <?php woocommerce_product_loop_end(); ?>

            <?php
            /**
             * Hook: woocommerce_after_shop_loop.
             *
             * @hooked woocommerce_pagination - 10
             */
            do_action( 'woocommerce_after_shop_loop' );
            ?>
                <div class="hr"></div>

        <?php else : ?>

            <?php
            /**
             * Hook: woocommerce_no_products_found.
             *
             * @hooked wc_no_products_found - 10
             */
            do_action( 'woocommerce_no_products_found' );
            ?>

        <?php endif; ?>

    </div>

    <?php
    /**
     * Hook: woocommerce_sidebar.
     *
     * @hooked woocommerce_get_sidebar - 10
     */
    if ( $shop_sidebar != 'full' ) {
        do_action( 'woocommerce_sidebar' );
    }
    ?>

</div>

<?php
/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action( 'woocommerce_after_main_content' );

get_footer( 'shop' );
?>
